@@ -1,10 +1,9 @@
 """Handle the game, runner and global system configurations."""
 
-# Standard Library
 import os
 import time
+from shutil import copyfile
 
-# Lutris Modules
 from lutris import settings, sysoptions
 from lutris.runners import InvalidRunner, import_runner
 from lutris.util.log import logger
@@ -17,6 +16,25 @@ def make_game_config_id(game_slug):
     return "{}-{}".format(game_slug, int(time.time()))
 
 
+def write_game_config(game_slug, config):
+    """Writes a game config to disk"""
+    configpath = make_game_config_id(game_slug)
+    logger.debug("Writing game config to %s", configpath)
+    config_filename = os.path.join(settings.CONFIG_DIR, "games/%s.yml" % configpath)
+    write_yaml_to_file(config, config_filename)
+    return configpath
+
+
+def duplicate_game_config(game_slug, source_config_id):
+    """Copies an existing configuration file, giving it a new id that this
+    function returns."""
+    new_config_id = make_game_config_id(game_slug)
+    src_path = os.path.join(settings.CONFIG_DIR, "games/%s.yml" % source_config_id)
+    dest_path = os.path.join(settings.CONFIG_DIR, "games/%s.yml" % new_config_id)
+    copyfile(src_path, dest_path)
+    return new_config_id
+
+
 class LutrisConfig:
 
     """Class where all the configuration handling happens.
